@@ -89,7 +89,6 @@ function(object,q,cond,int=NULL) {
         stop("gss error in cpssden: not a 1-D conditional density")
     mn <- min(object$domain[,xnames])
     mx <- max(object$domain[,xnames])
-    if (is.null(int)) int <- cdssden(object,mn,cond)$int
     order.q <- rank(q)
     p <- q <- sort(q)
     q.dup <- duplicated(q)
@@ -138,63 +137,37 @@ function(object,p,cond,int=NULL) {
         stop("gss error in cqssden: not a 1-D conditional density")
     mn <- min(object$domain[,xnames])
     mx <- max(object$domain[,xnames])
-    if (is.null(int)) int <- cdssden(object,mn,cond)$int
     order.p <- rank(p)
     q <- p <- sort(p)
     p.dup <- duplicated(p)
     q[p<=0] <- mn
     q[p>=1] <- mx
+    qd.hize <- 200
+    qd <- gauss.quad(2*qd.hize,c(mn,mx))
+    d.qd <- cdssden(object,qd$pt,cond,int)$pdf
+    gap <- diff(qd$pt)
+    g.wk <- gap[qd.hize]/2
+    for (i in 1:(qd.hize-2)) g.wk <- c(g.wk,gap[qd.hize+i]-g.wk[i])
+    g.wk <- 2*g.wk
+    g.wk <- c(g.wk,(mx-mn)/2-sum(g.wk))
+    gap[qd.hize:1] <- gap[qd.hize+(1:qd.hize)] <- g.wk
+    brk <- cumsum(c(mn,gap))
+    p.wk <- cumsum(d.qd*qd$wt)
     kk <- (1:length(p))[p>0&p<1]
-    quad <- gauss.quad(200,c(mn,mx))
-    q.wk <- quad$pt
-    p.wk <- cumsum(quad$wt*cdssden(object,q.wk,cond,int)$pdf)
     for (i in kk) {
         if (p.dup[i]) {
             q[i] <- q.dup
             next
         }
-        j <- which.min(abs(p[i]-p.wk))
-        q0 <- q.wk[j]
-        p0 <- cpssden(object,q0,cond,int)
-        if (p0==p[i]) {
-            q[i] <- q0
-            next
-        }
-        if (p0<p[i]) {
-            q.l <- q0
-            p.l <- p0
-            while (p0<p[i]) {
-                j <- j+1
-                q0 <- ifelse(is.null(q.wk[j]),mx,q.wk[j])
-                p0 <- cpssden(object,q0,cond,int)
-            }
-            q.u <- q0
-            p.u <- p0
+        ind <- (1:(2*qd.hize))[p.wk<p[i]]
+        if (!length(ind)) {
+            wk <- mn+p[i]/(d.qd[1]*qd$wt[1])*gap[1]
         }
         else {
-            q.u <- q0
-            p.u <- p0
-            while (p0>p[i]) {
-                j <- j-1
-                q0 <- ifelse(is.null(q.wk[j]),mn,q.wk[j])
-                p0 <- cpssden(object,q0,cond,int)
-            }
-            q.l <- q0
-            p.l <- p0
+            id.mx <- max(ind)
+            wk <- brk[id.mx+1]+(p[i]-p.wk[id.mx])/(d.qd[id.mx+1]*qd$wt[id.mx+1])*gap[id.mx+1]
         }
-        while (abs(p0-p[i])>1e-10) {
-            q0 <- q.l+(p[i]-p.l)/(p.u-p.l)*(q.u-q.l)
-            p0 <- cpssden(object,q0,cond,int)
-            if (p0>p[i]) {
-                q.u <- q0
-                p.u <- p0
-            }
-            else {
-                q.l <- q0
-                p.l <- p0
-            }
-        }
-        q[i] <- q.dup <- q0
+        q[i] <- q.dup <- wk
     }
     q[order.p]
 }
